@@ -416,6 +416,8 @@ PyAPI_FUNC(PyObject *) PyType_GenericNew(PyTypeObject *arg0, PyObject *arg1, PyO
 PyAPI_FUNC(int) PyType_IsSubtype(PyTypeObject *arg0, PyTypeObject *arg1);
 PyAPI_FUNC(void) PyType_Modified(PyTypeObject *arg0);
 PyAPI_FUNC(int) PyType_Ready(PyTypeObject *arg0);
+PyAPI_FUNC(PyObject *) PyUFunc_FromFuncAndData(void (***arg0)(char **, Signed *, Signed *, void *), void *arg1, char *arg2, Py_ssize_t arg3, Py_ssize_t arg4, Py_ssize_t arg5, Py_ssize_t arg6, char *arg7, char *arg8, Py_ssize_t arg9);
+PyAPI_FUNC(PyObject *) PyUFunc_FromFuncAndDataAndSignature(void (***arg0)(char **, Signed *, Signed *, void *), void *arg1, char *arg2, Py_ssize_t arg3, Py_ssize_t arg4, Py_ssize_t arg5, Py_ssize_t arg6, char *arg7, char *arg8, Py_ssize_t arg9, char *arg10);
 PyAPI_FUNC(char *) PyUnicode_AS_DATA(PyObject *arg0);
 PyAPI_FUNC(wchar_t *) PyUnicode_AS_UNICODE(PyObject *arg0);
 PyAPI_FUNC(PyObject *) PyUnicode_AsASCIIString(PyObject *arg0);
@@ -534,88 +536,88 @@ PyAPI_FUNC(PyObject *) _PyUnicode_AsDefaultEncodedString(PyObject *arg0, const c
 PyAPI_FUNC(Signed) _Py_HashPointer(void *arg0);
 PyAPI_FUNC(PyObject *) _Py_InitPyPyModule(const char *arg0, PyMethodDef *arg1, const char *arg2, PyObject *arg3, int arg4);
 PyAPI_FUNC(void) _Py_NewReference(PyObject *arg0);
-PyAPI_DATA(PyTypeObject) PyStaticMethod_Type;
-PyAPI_DATA(PyObject*) PyExc_EnvironmentError;
-PyAPI_DATA(PyTypeObject) PySlice_Type;
-PyAPI_DATA(PyObject*) PyExc_IOError;
-PyAPI_DATA(PyObject*) PyExc_RuntimeError;
-PyAPI_DATA(PyObject*) PyExc_AttributeError;
-PyAPI_DATA(PyObject*) PyExc_NameError;
-PyAPI_DATA(PyObject*) PyExc_MemoryError;
-PyAPI_DATA(PyObject*) PyExc_SystemExit;
-PyAPI_DATA(PyTypeObject) PyModule_Type;
-PyAPI_DATA(PyTypeObject) PyBaseObject_Type;
-PyAPI_DATA(PyObject*) PyExc_FloatingPointError;
-PyAPI_DATA(PyObject*) PyExc_UnicodeDecodeError;
-PyAPI_DATA(PyObject*) PyExc_Exception;
-PyAPI_DATA(PyObject*) PyExc_TypeError;
-PyAPI_DATA(PyObject*) PyExc_SystemError;
-PyAPI_DATA(PyObject*) PyExc_ReferenceError;
-PyAPI_DATA(PyTypeObject) PyNone_Type;
-PyAPI_DATA(PyTypeObject) PySet_Type;
-PyAPI_DATA(PyObject*) PyExc_TabError;
-PyAPI_DATA(PyTypeObject) PyDict_Type;
-PyAPI_DATA(PyTypeObject) PyByteArray_Type;
-PyAPI_DATA(PyTypeObject) PyList_Type;
-PyAPI_DATA(PyTypeObject) PyBaseString_Type;
-PyAPI_DATA(PyTypeObject) PyWrapperDescr_Type;
-PyAPI_DATA(PyObject*) PyExc_PendingDeprecationWarning;
-PyAPI_DATA(PyObject*) PyExc_OverflowError;
-PyAPI_DATA(PyObject*) PyExc_BaseException;
-PyAPI_DATA(PyObject*) PyExc_StandardError;
-PyAPI_DATA(PyObject*) PyExc_Warning;
-PyAPI_DATA(PyTypeObject) PyTuple_Type;
-PyAPI_DATA(PyObject*) PyExc_UnicodeError;
-PyAPI_DATA(PyTypeObject) PyProperty_Type;
-PyAPI_DATA(PyObject*) PyExc_IndexError;
-PyAPI_DATA(PyTypeObject) PyCell_Type;
-PyAPI_DATA(PyObject*) PyExc_FutureWarning;
+PyAPI_DATA(PyObject) _Py_NoneStruct;
+PyAPI_DATA(PyObject) _Py_TrueStruct;
 PyAPI_DATA(PyObject) _Py_ZeroStruct;
-PyAPI_DATA(PyObject*) PyExc_UnboundLocalError;
 PyAPI_DATA(PyObject) _Py_NotImplementedStruct;
-PyAPI_DATA(PyTypeObject) PyComplex_Type;
-PyAPI_DATA(PyTypeObject) PyFloat_Type;
-PyAPI_DATA(PyTypeObject) PyUnicode_Type;
-PyAPI_DATA(PyTypeObject) PyCFunction_Type;
-PyAPI_DATA(PyTypeObject) PyArray_Type;
+PyAPI_DATA(PyObject) _Py_EllipsisObject;
+PyAPI_DATA(PyDateTime_CAPI*) PyDateTimeAPI;
+PyAPI_DATA(PyObject*) PyExc_ArithmeticError;
+PyAPI_DATA(PyObject*) PyExc_AssertionError;
+PyAPI_DATA(PyObject*) PyExc_AttributeError;
+PyAPI_DATA(PyObject*) PyExc_BaseException;
+PyAPI_DATA(PyObject*) PyExc_BufferError;
 PyAPI_DATA(PyObject*) PyExc_BytesWarning;
 PyAPI_DATA(PyObject*) PyExc_DeprecationWarning;
-PyAPI_DATA(PyObject*) PyExc_SyntaxError;
-PyAPI_DATA(PyObject*) PyExc_UnicodeWarning;
-PyAPI_DATA(PyObject*) PyExc_ZeroDivisionError;
-PyAPI_DATA(PyTypeObject) PyFrozenSet_Type;
-PyAPI_DATA(PyObject*) PyExc_RuntimeWarning;
-PyAPI_DATA(PyObject) _Py_NoneStruct;
-PyAPI_DATA(PyObject*) PyExc_IndentationError;
-PyAPI_DATA(PyObject*) PyExc_AssertionError;
-PyAPI_DATA(PyObject*) PyExc_GeneratorExit;
-PyAPI_DATA(PyObject*) PyExc_ImportWarning;
-PyAPI_DATA(PyObject*) PyExc_UnicodeEncodeError;
-PyAPI_DATA(PyTypeObject) PyInt_Type;
-PyAPI_DATA(PyTypeObject) PyNotImplemented_Type;
-PyAPI_DATA(PyTypeObject) PyString_Type;
-PyAPI_DATA(PyTypeObject) PyBool_Type;
-PyAPI_DATA(PyObject*) PyExc_OSError;
-PyAPI_DATA(PyObject*) PyExc_KeyError;
-PyAPI_DATA(PyObject*) PyExc_SyntaxWarning;
-PyAPI_DATA(PyObject*) PyExc_StopIteration;
-PyAPI_DATA(PyObject*) PyExc_NotImplementedError;
-PyAPI_DATA(PyObject*) PyExc_ImportError;
-PyAPI_DATA(PyDateTime_CAPI*) PyDateTimeAPI;
-PyAPI_DATA(PyObject*) PyExc_UserWarning;
-PyAPI_DATA(PyObject) _Py_TrueStruct;
-PyAPI_DATA(PyObject*) PyExc_ArithmeticError;
-PyAPI_DATA(PyTypeObject) PyClass_Type;
-PyAPI_DATA(PyTypeObject) PyType_Type;
-PyAPI_DATA(PyTypeObject) PyMemoryView_Type;
-PyAPI_DATA(PyObject*) PyExc_UnicodeTranslateError;
-PyAPI_DATA(PyTypeObject) PyLong_Type;
-PyAPI_DATA(PyObject*) PyExc_LookupError;
 PyAPI_DATA(PyObject*) PyExc_EOFError;
-PyAPI_DATA(PyObject*) PyExc_BufferError;
-PyAPI_DATA(PyObject*) PyExc_ValueError;
-PyAPI_DATA(PyObject) _Py_EllipsisObject;
+PyAPI_DATA(PyObject*) PyExc_EnvironmentError;
+PyAPI_DATA(PyObject*) PyExc_Exception;
+PyAPI_DATA(PyObject*) PyExc_FloatingPointError;
+PyAPI_DATA(PyObject*) PyExc_FutureWarning;
+PyAPI_DATA(PyObject*) PyExc_GeneratorExit;
+PyAPI_DATA(PyObject*) PyExc_IOError;
+PyAPI_DATA(PyObject*) PyExc_ImportError;
+PyAPI_DATA(PyObject*) PyExc_ImportWarning;
+PyAPI_DATA(PyObject*) PyExc_IndentationError;
+PyAPI_DATA(PyObject*) PyExc_IndexError;
+PyAPI_DATA(PyObject*) PyExc_KeyError;
 PyAPI_DATA(PyObject*) PyExc_KeyboardInterrupt;
+PyAPI_DATA(PyObject*) PyExc_LookupError;
+PyAPI_DATA(PyObject*) PyExc_MemoryError;
+PyAPI_DATA(PyObject*) PyExc_NameError;
+PyAPI_DATA(PyObject*) PyExc_NotImplementedError;
+PyAPI_DATA(PyObject*) PyExc_OSError;
+PyAPI_DATA(PyObject*) PyExc_OverflowError;
+PyAPI_DATA(PyObject*) PyExc_PendingDeprecationWarning;
+PyAPI_DATA(PyObject*) PyExc_ReferenceError;
+PyAPI_DATA(PyObject*) PyExc_RuntimeError;
+PyAPI_DATA(PyObject*) PyExc_RuntimeWarning;
+PyAPI_DATA(PyObject*) PyExc_StandardError;
+PyAPI_DATA(PyObject*) PyExc_StopIteration;
+PyAPI_DATA(PyObject*) PyExc_SyntaxError;
+PyAPI_DATA(PyObject*) PyExc_SyntaxWarning;
+PyAPI_DATA(PyObject*) PyExc_SystemExit;
+PyAPI_DATA(PyObject*) PyExc_SystemError;
+PyAPI_DATA(PyObject*) PyExc_TabError;
+PyAPI_DATA(PyObject*) PyExc_TypeError;
+PyAPI_DATA(PyObject*) PyExc_UnboundLocalError;
+PyAPI_DATA(PyObject*) PyExc_UnicodeDecodeError;
+PyAPI_DATA(PyObject*) PyExc_UnicodeEncodeError;
+PyAPI_DATA(PyObject*) PyExc_UnicodeError;
+PyAPI_DATA(PyObject*) PyExc_UnicodeTranslateError;
+PyAPI_DATA(PyObject*) PyExc_UnicodeWarning;
+PyAPI_DATA(PyObject*) PyExc_UserWarning;
+PyAPI_DATA(PyObject*) PyExc_ValueError;
+PyAPI_DATA(PyObject*) PyExc_Warning;
+PyAPI_DATA(PyObject*) PyExc_ZeroDivisionError;
+PyAPI_DATA(PyTypeObject) PyType_Type;
+PyAPI_DATA(PyTypeObject) PyString_Type;
+PyAPI_DATA(PyTypeObject) PyUnicode_Type;
+PyAPI_DATA(PyTypeObject) PyBaseString_Type;
+PyAPI_DATA(PyTypeObject) PyDict_Type;
+PyAPI_DATA(PyTypeObject) PyTuple_Type;
+PyAPI_DATA(PyTypeObject) PyList_Type;
+PyAPI_DATA(PyTypeObject) PySet_Type;
+PyAPI_DATA(PyTypeObject) PyFrozenSet_Type;
+PyAPI_DATA(PyTypeObject) PyInt_Type;
+PyAPI_DATA(PyTypeObject) PyBool_Type;
+PyAPI_DATA(PyTypeObject) PyFloat_Type;
+PyAPI_DATA(PyTypeObject) PyLong_Type;
+PyAPI_DATA(PyTypeObject) PyComplex_Type;
+PyAPI_DATA(PyTypeObject) PyByteArray_Type;
+PyAPI_DATA(PyTypeObject) PyMemoryView_Type;
+PyAPI_DATA(PyTypeObject) PyArray_Type;
+PyAPI_DATA(PyTypeObject) PyBaseObject_Type;
+PyAPI_DATA(PyTypeObject) PyNone_Type;
+PyAPI_DATA(PyTypeObject) PyNotImplemented_Type;
+PyAPI_DATA(PyTypeObject) PyCell_Type;
+PyAPI_DATA(PyTypeObject) PyModule_Type;
+PyAPI_DATA(PyTypeObject) PyProperty_Type;
+PyAPI_DATA(PyTypeObject) PySlice_Type;
+PyAPI_DATA(PyTypeObject) PyClass_Type;
+PyAPI_DATA(PyTypeObject) PyStaticMethod_Type;
+PyAPI_DATA(PyTypeObject) PyCFunction_Type;
+PyAPI_DATA(PyTypeObject) PyWrapperDescr_Type;
 #undef Signed    /* xxx temporary fix */
 
 #undef Unsigned  /* xxx temporary fix */
